=== modified file 'drizzled/handler_structs.h'
--- drizzled/handler_structs.h	2008-11-12 17:42:40 +0000
+++ drizzled/handler_structs.h	2008-11-19 19:49:27 +0000
@@ -107,7 +107,6 @@
   uint32_t options;                         /* OR of HA_CREATE_ options */
   uint32_t extra_size;                      /* length of extra data segment */
   bool table_existed;			/* 1 in create if table existed */
-  bool frm_only;                        /* 1 if no ha_create_table() */
   bool varchar;                         /* 1 if table has a VARCHAR */
   enum ha_choice page_checksum;         /* If we have page_checksums */
 } HA_CREATE_INFO;

=== modified file 'drizzled/server_includes.h'
--- drizzled/server_includes.h	2008-11-18 22:12:56 +0000
+++ drizzled/server_includes.h	2008-11-19 19:49:27 +0000
@@ -58,7 +58,6 @@
 #define is_schema_db(X) \
   !my_strcasecmp(system_charset_info, INFORMATION_SCHEMA_NAME.str, (X))
 
-
 /* sql_calc.cc */
 bool eval_const_cond(COND *cond);
 

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2008-11-19 08:07:10 +0000
+++ drizzled/sql_base.cc	2008-11-19 19:49:27 +0000
@@ -1573,13 +1573,10 @@
 
   free_io_cache(table);
   closefrm(table, 0);
-  /*
-     Check that temporary table has not been created with
-     frm_only because it has then not been created in any storage engine
-   */
+
   if (delete_table)
-    rm_temporary_table(table_type, table->s->path.str, 
-                       table->s->tmp_table == TMP_TABLE_FRM_FILE_ONLY);
+    rm_temporary_table(table_type, table->s->path.str);
+
   if (free_share)
   {
     free_table_share(table->s);
@@ -3856,7 +3853,7 @@
 }
 
 
-bool rm_temporary_table(handlerton *base, char *path, bool frm_only)
+bool rm_temporary_table(handlerton *base, char *path)
 {
   bool error=0;
   handler *file;
@@ -3869,7 +3866,7 @@
     error=1; /* purecov: inspected */
   *ext= 0;				// remove extension
   file= get_new_handler((TABLE_SHARE*) 0, current_session->mem_root, base);
-  if (!frm_only && file && file->ha_delete_table(path))
+  if (file && file->ha_delete_table(path))
   {
     error=1;
     sql_print_warning(_("Could not remove temporary table: '%s', error: %d"),

=== modified file 'drizzled/sql_base.h'
--- drizzled/sql_base.h	2008-11-18 22:12:56 +0000
+++ drizzled/sql_base.h	2008-11-19 19:49:27 +0000
@@ -161,7 +161,7 @@
 Table *open_temporary_table(Session *session, const char *path, const char *db,
                             const char *table_name, bool link_in_list,
                             open_table_mode open_mode);
-bool rm_temporary_table(handlerton *base, char *path, bool frm_only);
+bool rm_temporary_table(handlerton *base, char *path);
 void free_io_cache(Table *entry);
 void intern_close_table(Table *entry);
 bool close_thread_table(Session *session, Table **table_ptr);

=== modified file 'drizzled/sql_delete.cc'
--- drizzled/sql_delete.cc	2008-11-18 22:12:56 +0000
+++ drizzled/sql_delete.cc	2008-11-19 19:49:27 +0000
@@ -843,7 +843,6 @@
   {
     handlerton *table_type= table->s->db_type();
     TABLE_SHARE *share= table->s;
-    bool frm_only= (share->tmp_table == TMP_TABLE_FRM_FILE_ONLY);
 
     if (!ha_check_storage_engine_flag(table_type, HTON_CAN_RECREATE))
       goto trunc_by_del;
@@ -858,7 +857,7 @@
                                              share->db.str,
 					     share->table_name.str, 1,
                                              OTM_OPEN))))
-      (void) rm_temporary_table(table_type, path, frm_only);
+      (void) rm_temporary_table(table_type, path);
     free_table_share(share);
     free((char*) table);
     /*

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2008-11-15 17:33:00 +0000
+++ drizzled/sql_table.cc	2008-11-19 19:49:27 +0000
@@ -1913,7 +1913,7 @@
     /* Open table and put in temporary table list */
     if (!(open_temporary_table(session, path, db, table_name, 1, OTM_OPEN)))
     {
-      (void) rm_temporary_table(create_info->db_type, path, false);
+      (void) rm_temporary_table(create_info->db_type, path);
       goto unlock_and_end;
     }
     session->thread_specific_used= true;
@@ -3045,7 +3045,7 @@
                                      OTM_OPEN))
     {
       (void) rm_temporary_table(create_info->db_type,
-				dst_path, false); /* purecov: inspected */
+				dst_path);
       goto err;     /* purecov: inspected */
     }
   }
@@ -3745,7 +3745,6 @@
 
   /*
     Create a table with a temporary name.
-    With create_info->frm_only == 1 this creates a .frm file only.
     We don't log the statement, it will be logged later.
   */
   tmp_disable_binlog(session);
@@ -3795,7 +3794,7 @@
   if (lower_case_table_names)
     my_casedn_str(files_charset_info, tmp_name);
   altered_create_info.options&= ~HA_LEX_CREATE_TMP_TABLE;
-  altered_create_info.frm_only= 1;
+
   if ((error= create_temporary_table(session, table, new_db, tmp_name,
                                      &altered_create_info,
                                      alter_info, db_change)))

=== modified file 'drizzled/unireg.cc'
--- drizzled/unireg.cc	2008-11-16 18:20:33 +0000
+++ drizzled/unireg.cc	2008-11-19 19:49:27 +0000
@@ -662,7 +662,7 @@
     create_info->options|= HA_CREATE_KEEP_FILES;
   if (file->ha_create_handler_files(path, NULL, CHF_CREATE_FLAG, create_info))
     goto err_handler;
-  if (!create_info->frm_only && ha_create_table(session, path, db, table_name,
+  if ( ha_create_table(session, path, db, table_name,
                                                 create_info,0))
     goto err_handler;
   return(0);

